Learn R Programming

downloader (version 0.2.1)

source_url: Download an R file from a URL and source it

Description

This will download a file and source it. Because it uses the download function, it can handle https URLs.

Usage

source_url(url, ...)

Arguments

See Also

source() for more information on the arguments that can be used with this function.

Examples

Run this code
# Source the download.r file from the downloader package
source_url("https://raw.github.com/wch/downloader/master/R/download.r")

Run the code above in your browser using DataLab